/*
 *  Copyright(c)2002 Forward Computing and Control Pty. Ltd.
 *  ACN 003 669 994, NSW, Australia      All rights Reserved
 *  
 *   Written by Dr. M.P. Ford
 *
 *  ThreadReturn package Copyright (c) 2003 Forward Computing and Control Pty. Ltd.
 *  NSW. Australia,  www.forward.com.au
 *  All rights reserved.
 *  
 *  Redistribution of the source of this package, with or without
 *  modification, is NOT permitted.
 *  
 *  Redistribution of the compiled java .class files of this package, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions in compiled java .class form must reproduce the above
 *     copyright notice, this list of conditions and the following disclaimer
 *     in the documentation and/or other materials provided with the distribution.
 *  2. If the software is modified, the compiled java .class distribution must
 *     include, in the documentation and/or other materials provided with the 
 *     distribution, a statement that the software has been modified and
 *     identify the person who was responsable for the modifications.  
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 *  IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 *  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 *  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */
package au.com.forward.threads;

import java.io.PrintWriter;
import java.io.StringWriter;

/**
 *  The <code>static</code> {@link #toString toString(Throwable t)} method of this class 
 *  is used to retrieve the contents of an exception's stack trace as a <code>String</code>.
 *
 * @author     Matthew Ford 
 * @created    5 May 2002 
 * @version    1.0 28/04/2002 
 */
public class StackTrace {

	/** 
	 * No instance of this class is ever constructed
	 */
	private StackTrace() {
	}
	
	/**
	 *  Returns the <code>Throwable</code>'s stack trace as a <code>String</code>. 
	 *
	 * @param  e  the <code>Throwable</code> to convert to a <code>String</code>. 
	 * @return    the contents of stack trace or the string "Throwable parameter was null." if the
	 *           input arguement was <code>null</code>.
	 */
	public static String toString(Throwable e) {
		if (e == null) {
			return "Throwable parameter was null.";
		}
		StringWriter strWriter = new StringWriter();
		PrintWriter printWriter = new PrintWriter(strWriter);
		e.printStackTrace(printWriter);
		return strWriter.toString();
	}
}