/*
 *  Copyright(c)2002 Forward Computing and Control Pty. Ltd.
 *  ACN 003 669 994, NSW, Australia      All rights Reserved
 *  
 *   Written by Dr. M.P. Ford
 *   
 *  ThreadReturn package Copyright (c) 2003 Forward Computing and Control Pty. Ltd.
 *  NSW. Australia,  www.forward.com.au
 *  All rights reserved.
 *  
 *  Redistribution of the source of this package, with or without
 *  modification, is NOT permitted.
 *  
 *  Redistribution of the compiled java .class files of this package, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions in compiled java .class form must reproduce the above
 *     copyright notice, this list of conditions and the following disclaimer
 *     in the documentation and/or other materials provided with the distribution.
 *  2. If the software is modified, the compiled java .class distribution must
 *     include, in the documentation and/or other materials provided with the 
 *     distribution, a statement that the software has been modified and
 *     identify the person who was responsable for the modifications.  
 *  3. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 *  IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 *  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 *  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *   
 *
 */
package au.com.forward.threads;
import java.util.EventListener;

/**
 *  A listener for thread termination events. <p>
 * The effectiveness of this interface
 * depends on the use of an outer <code>try/catch</code> block in the thread's <code>run()</code>
 * method and the addition of {@link ThreadReturn#save ThreadReturn.save(Object)} statements.&nbsp;
 * See {@link ThreadReturn} for more details.
 *  
 *
 * @author     matthew ford 
 * @created    5 May 2002 
 */
public interface ThreadListener extends EventListener {

	/**
	 *  Called when the thread died normally.&nbsp; Any exception thrown by this method 
	 *  will be passed to {@link #threadError threadError(ThreadEvent e)}. 
	 * <p>
	* <b>NOTE:</b>{@link ThreadListener#threadResult threadResult(ThreadEvent e)} should not modify the
	* result <code>Object</code> contained in the {@link ThreadEvent} because the same result <code>Object</code>
	* will be passed on to the other registered listeners for this thread. 
	 *
	 * @param  e  the {@link ThreadEvent}
	 */
	public void threadResult(ThreadEvent e);

	/**
	 *  Called when the thread was stopped by being interrupted.&nbsp;
	 *  I.e. the thread saved an exception of class <code>InterruptedException</code>
	 *  or <code>ClosedByInterruptException</code>.&nbsp; Any exception thrown by this method 
	 *  will be passed to {@link #threadError threadError(ThreadEvent e)}. 
	 * <p>
	* <b>NOTE:</b>{@link ThreadListener#threadInterrupted threadInterrupted(ThreadEvent e)} should not modify the
	* result <code>Object</code> contained in the {@link ThreadEvent} because the same result <code>Object</code>
	* will be passed on to the other registered listeners for this thread. 
	 *
	 * @param  e  the {@link ThreadEvent}
	 */
	public void threadInterrupted(ThreadEvent e);

	/**
	 *  Called when an error occured on the thread or an error occurred in the 
	 *  observer thread.&nbsp; This interface method will also be called if any exception is thrown by
	 *  {@link #threadResult threadResult(ThreadEvent e)} or {@link #threadInterrupted threadInterrupted(ThreadEvent e)}
	 * or by the thread that is monitoring the thread
	 * being listened to.
	 * <p>
	 *  All <code>Throwable</code> objects thrown by this interface method, {@link #threadError threadError},
	 * are caught and ignored.&nbsp; It is your responsibility to catch and handle <em>ALL</em> 
	 *  <code>Throwable</code> objects thrown by this method. 
	 *
	 * @param  e  the {@link ThreadEvent} 
	 */
	public void threadError(ThreadEvent e);

}